summaryrefslogtreecommitdiffstats
path: root/mpeglib/lib/output/outputStream.h
diff options
context:
space:
mode:
Diffstat (limited to 'mpeglib/lib/output/outputStream.h')
-rw-r--r--mpeglib/lib/output/outputStream.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpeglib/lib/output/outputStream.h b/mpeglib/lib/output/outputStream.h
index 9ef538fd..6dccd02e 100644
--- a/mpeglib/lib/output/outputStream.h
+++ b/mpeglib/lib/output/outputStream.h
@@ -105,10 +105,10 @@ class KDE_EXPORT OutputStream {
// stream State handling
// we return the mask which triggerd (by "AND")
// or the current polled mask when method is POLL
// Note: you can only wait for "true" signals
- virtual int waitStreamState(int method,int mask,int streamType);
+ virtual int waitStreamState(int method,int tqmask,int streamType);
@@ -105,10 +105,10 @@ class KDE_EXPORT OutputStream {
// stream State handling
- // we return the mask which triggerd (by "AND")
- // or the current polled mask when method is POLL
+ // we return the tqmask which triggerd (by "AND")
+ // or the current polled tqmask when method is POLL
// Note: you can only wait for "true" signals